@@ -303,7 +303,14 @@ class SMBDirectory:
 						if res is False:
 							continue
 					obj.tree_id = self.tree_id
-					async for e,t,err in obj.list_r(connection, depth, maxentries = maxentries, exclude_dir = exclude_dir):
+					async for e,t,err in obj.list_r(
+							connection, 
+							depth, 
+							maxentries = maxentries, 
+							exclude_dir = exclude_dir,
+							fetch_dir_sd = fetch_dir_sd, 
+							fetch_file_sd = fetch_file_sd,
+							filter_cb = filter_cb):
 						yield e,t,err
 						# await asyncio.sleep(0)
 		except Exception as e:
